@@ -5,12 +5,6 @@ from typing import List, NamedTuple, Optional
 
 import ib_insync.util as util
 
-__all__ = (
-    'Contract Stock Option Future ContFuture Forex Index CFD '
-    'Commodity Bond FuturesOption MutualFund Warrant Bag Crypto '
-    'TagValue ComboLeg DeltaNeutralContract ContractDetails '
-    'ContractDescription ScanData').split()
-
 
 @dataclass
 class Contract:
@@ -101,6 +95,8 @@ class Contract:
     includeExpired: bool = False
     secIdType: str = ''
     secId: str = ''
+    description: str = ''
+    issuerId: str = ''
     comboLegsDescrip: str = ''
     comboLegs: List['ComboLeg'] = field(default_factory=list)
     deltaNeutralContract: Optional['DeltaNeutralContract'] = None
@@ -470,7 +466,6 @@ class ContractDetails:
     contract: Optional[Contract] = None
     marketName: str = ''
     minTick: float = 0.0
-    sizeMinTick: float = 0.0
     orderTypes: str = ''
     validExchanges: str = ''
     priceMagnifier: int = 0
@@ -485,7 +480,7 @@ class ContractDetails:
     liquidHours: str = ''
     evRule: str = ''
     evMultiplier: int = 0
-    mdSizeMultiplier: int = 0
+    mdSizeMultiplier: int = 1  # obsolete
     aggGroup: int = 0
     underSymbol: str = ''
     underSecType: str = ''
@@ -494,6 +489,10 @@ class ContractDetails:
     realExpirationDate: str = ''
     lastTradeTime: str = ''
     stockType: str = ''
+    minSize: float = 0.0
+    sizeIncrement: float = 0.0
+    suggestedSizeIncrement: float = 0.0
+    # minCashQtySize: float = 0.0
     cusip: str = ''
     ratings: str = ''
     descAppend: str = ''
@@ -501,7 +500,7 @@ class ContractDetails:
     couponType: str = ''
     callable: bool = False
     putable: bool = False
-    coupon: int = 0
+    coupon: float = 0
     convertible: bool = False
     maturity: str = ''
     issueDate: str = ''
