@@ -13,8 +13,6 @@ from ib_insync.objects import (
     TickData)
 from ib_insync.util import dataclassRepr, isNan
 
-__all__ = ['Ticker']
-
 nan = float('nan')
 
 
@@ -46,12 +44,16 @@ class Ticker:
     contract: Optional[Contract] = None
     time: Optional[datetime] = None
     marketDataType: int = 1
+    minTick: float = nan
     bid: float = nan
     bidSize: float = nan
+    bidExchange: str = ''
     ask: float = nan
     askSize: float = nan
+    askExchange: str = ''
     last: float = nan
     lastSize: float = nan
+    lastExchange: str = ''
     prevBid: float = nan
     prevBidSize: float = nan
     prevAsk: float = nan
@@ -109,6 +111,9 @@ class Ticker:
     auctionVolume: float = nan
     auctionPrice: float = nan
     auctionImbalance: float = nan
+    regulatoryImbalance: float = nan
+    bboExchange: str = ''
+    snapshotPermissions: int = 0
 
     def __post_init__(self):
         self.updateEvent = TickerUpdateEvent('updateEvent')
@@ -139,15 +144,16 @@ class Ticker:
         """
         Return the first available one of
 
-        * last price if within current bid/ask;
-        * average of bid and ask (midpoint);
-        * close price.
+        * last price if within current bid/ask or no bid/ask available;
+        * average of bid and ask (midpoint).
         """
-        price = self.last if (
-            self.hasBidAsk() and self.bid <= self.last <= self.ask) else \
-            self.midpoint()
-        if isNan(price):
-            price = self.close
+        if self.hasBidAsk():
+            if self.bid <= self.last <= self.ask:
+                price = self.last
+            else:
+                price = self.midpoint()
+        else:
+            price = self.last
         return price
 
 
